==========
Change log
==========

2.1 (2016-12-06)
================

- Add compatibility with `setuptools >= 30.0`.


2.0 (2016-06-17)
================

- Use a default configuration file named ``toll.ini``. This can be overwritten
  using ``-c`` when calling `toll`.

- Allow to specify multiple command which should be called. (See ``--help``.)

- Make package compatible with Python 2.7, 3.3, 3.4 and PyPy.


1.0 (2016-02-26)
================

* Initial release.
